@@ -156,6 +156,56 @@ setMethod(
   }
 )
 
+
+#' Display column tree structure
+#'
+#' Displays the tree structure of the columns of a
+#' table or column structure object.
+#'
+#' @inheritParams gen_args
+#'
+#' @return Nothing, called for its side effect of displaying
+#' a summary to the terminal.
+#'
+#' @examples
+#' lyt <- basic_table() %>%
+#'   split_cols_by("ARM") %>%
+#'   split_cols_by("STRATA1") %>%
+#'   split_cols_by("SEX", nested = FALSE) %>%
+#'   analyze("AGE")
+#'
+#' tbl <- build_table(lyt, ex_adsl)
+#' coltree_structure(tbl)
+#' @export
+coltree_structure <- function(obj) {
+  ctree <- coltree(obj)
+  cat(layoutmsg2(ctree))
+}
+
+lastposmsg <- function(pos) {
+  spls <- pos_splits(pos)
+  splvals <- value_names(pos_splvals(pos))
+  indiv_msgs <- unlist(mapply(function(spl, valnm) paste(obj_name(spl), valnm, sep = ": "),
+    spl = spls,
+    valnm = splvals,
+    SIMPLIFY = FALSE
+  ))
+  paste(indiv_msgs, collapse = " -> ")
+}
+
+layoutmsg2 <- function(obj, level = 1) {
+  nm <- obj_name(obj)
+  pos <- tree_pos(obj)
+  nopos <- identical(pos, EmptyTreePos)
+
+  msg <- paste0(strrep(" ", times = 2 * (level - 1)), "[", nm, "] (", if (nopos) "no pos" else lastposmsg(pos), ")\n")
+  if (is(obj, "LayoutAxisTree")) {
+    kids <- tree_children(obj)
+    msg <- c(msg, unlist(lapply(kids, layoutmsg2, level = level + 1)))
+  }
+  msg
+}
+
 setGeneric("spltype_abbrev", function(obj) standardGeneric("spltype_abbrev"))
 
 setMethod(
